from lilliepy_dir_router import FileRouter
from lilliepy_bling import _server
from lilliepy_head import Meta, Title, Favicon
from lilliepy_statics import use_CSS, use_JS, use_media, static
from lilliepy_query import use_query, Fetcher
from lilliepy_state import FSMContainer, StateContainer, use_store
from lilliepy_import import Importer, _import
from reactpy import *
from reactpy_router import *
import reactpy_forms as Forms
import reactpy_table as Table
import reactpy_select as Select
import reactpy_flake8 as Enforce
import reactpy_apexcharts as Charts

__all__ = list(globals())



from setuptools import setup, find_packages

setup(
    name="lilliepy",
    version="2.0.1",
    author="sarthak ghoshal",  
    author_email="sarthak22.ghoshal@example.com",  
    description="A Bundle of Pkgs for Lilliepy",
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/websitedeb/lilliepy",  
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "reactpy",
        "reactpy-router",
        "reactpy-forms",
        "reactpy-table",
        "reactpy-select",
        "reactpy-flake8",
        "reactpy-apexcharts",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
